==> fileslog-1.0.2.tar.gz: fileslog/src/Form/FileslogClearLogConfirmForm.php <==
<?php

namespace Drupal\fileslog\Form;

use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\fileslog\Logger\FilesLog;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a confirmation form before clearing out the logs.
 */
class FileslogClearLogConfirmForm extends ConfirmFormBase {

  /**
   * The filesystem service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected FileSystemInterface $fileSystem;

  /**
   * Constructs a new FileslogClearLogConfirmForm.
   *
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The filesystem service.
   */
  public function __construct(FileSystemInterface $file_system) {
    $this->fileSystem = $file_system;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('file_system')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'fileslog_confirm';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the recent logs?');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('fileslog.overview');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $files = $this->fileSystem->scanDirectory(FilesLog::DIRECTORY, '/(.?)\.json/', ['recurse' => FALSE]);
    foreach ($files as $uri => $file) {
      $this->fileSystem->unlink($uri);
    }
    $this->messenger()->addStatus($this->t('Files log cleared.'));
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}

==> fileslog-1.0.4.tar.gz: fileslog/src/Form/FileslogClearLogConfirmForm.php <==
<?php

namespace Drupal\fileslog\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\fileslog\FilesLogManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a confirmation form before clearing out the logs.
 */
class FileslogClearLogConfirmForm extends ConfirmFormBase {

  /**
   * The fileslog manager.
   *
   * @var \Drupal\fileslog\FilesLogManager
   */
  protected FilesLogManager $filesLogManager;

  /**
   * Constructs a new FileslogClearLogConfirmForm.
   *
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The filesystem service.
   */
  public function __construct(FilesLogManager $files_log_manager) {
    $this->filesLogManager = $files_log_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('fileslog.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'fileslog_clear_log_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the recent logs?');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('fileslog.overview');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->filesLogManager->deleteLogs();
    $this->messenger()->addStatus($this->t('Files log cleared.'));
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
